@@ -28,7 +28,10 @@ APIS = {
     'trends':'GOOGLE_TRENDS',
     'news_polish':'INTERIA',
     'concerts':'SONGKICK',
-    'nu': 'NU'
+    'nu': 'NU',
+    'solaredge': 'SOLAREDGE',
+    'countdown': 'COUNTDOWN',
+    'twitter': 'TWITTER'
 }
 
 VIDEO_EXTENSIONS = [ext for ext in mimetypes.types_map if mimetypes.types_map[ext].split('/')[0] == 'video']
