@@ -480,6 +480,10 @@ class Log:
             self.debug = False
     
     def log(self, msg):
+        svars = variables()
+        self.debug = svars['Player.debug_python']
         if (self.level == NAMELEVEL['DEBUG'] and self.debug) or not self.level == NAMELEVEL['DEBUG']:
             log(self.level, '{}: {}'.format(self.script, msg))
+    
+
 
